Package: maGUI
Type: Package
Title: A Graphical User Interface for Microarray Data Analysis and
        Annotation
Version: 4.0
Date: 2022-04-12
Author: Dhammapal Bharne
Maintainer: Dhammapal Bharne <dhammapalb@gmail.com>
Imports: tcltk, grDevices, utils, Biobase
SystemRequirements: Tktable (>= 2.10)
Suggests: tkrplot, gWidgets2, Rgraphviz, ssize, Biostrings,
        BiocManager, RSQLite, GEOquery, GEOmetadb, RBGL, WGCNA,
        KEGGREST, KEGGgraph, pdInfoBuilder, lumi, oligo, graph, affy,
        genefilter, beadarray, GOstats, GO.db, Category, annotate,
        impute, limma, graphics, methods, stats
Description: Provides a comprehensive graphical user interface for analysis of Affymetrix, Agilent, Illumina, Nimblegen and other microarray data. It can perform miscellaneous tasks such as gene set enrichment and test analyses, identifying gene symbols and building co-expression network. It can also estimate sample size for atleast two-fold expression change. The current version is its slenderized form for compatable and flexible implementation.
License: GPL-2
LazyLoad: yes
NeedsCompilation: no
Packaged: 2022-04-11 21:49:27 UTC; dhamma
Repository: CRAN
Date/Publication: 2022-04-11 22:22:28 UTC
Built: R 4.6.0; ; 2026-04-25 20:09:36 UTC; unix
